@@ -120,7 +120,7 @@ parser.add_argument("--no-json", help=argparse.SUPPRESS, action="store_false", d
 # * No temporary project is created (if building an app) and the
 #   "project" field is not set in the app spec.
 parser.set_defaults(dry_run=False)
-parser.add_argument("--dry-run", help="Do not create an app(let), only show the spec of the applet that would have been created.", action="store_true", dest="dry_run")
+parser.add_argument("--dry-run", "-n", help="Do not create an app(let): only perform local checks and compilation steps, and show the spec of the app(let) that would have been created.", action="store_true", dest="dry_run")
 parser.add_argument("--no-dry-run", help=argparse.SUPPRESS, action="store_false", dest="dry_run")
 
 
@@ -258,9 +258,9 @@ def _check_file_syntax(filename, override_lang=None):
     Raises subprocess.CalledProcessError if there is a problem.
     """
     def check_python(filename):
-        subprocess.check_output("%s -m py_compile %s 2>&1" % (sys.executable, filename), shell=True)
+        subprocess.check_output([sys.executable, "-m", "py_compile", filename], stderr=subprocess.STDOUT)
     def check_bash(filename):
-        subprocess.check_output("/bin/bash -n %s 2>&1" % (filename,), shell=True)
+        subprocess.check_output(["/bin/bash", "-n", filename], stderr=subprocess.STDOUT)
 
     if override_lang == 'python2.7':
         checker_fn = check_python
@@ -352,14 +352,11 @@ def _build_app_remote(mode, src_dir, publish=False, destination_override=None,
     # interior call of dx-build-app, because within the execution
     # environment of tarball_app(let)_builder, APISERVER_HOST is set to
     # the address of the proxy (a 10.x.x.x address) and doesn't give us
-    # any information about whether we are talking to preprod.
+    # any information about whether we are talking to prod or not.
     if dx_toolkit_autodep == "auto":
-        # "auto" (the default) means dx-toolkit (stable) on preprod and prod, and
+        # "auto" (the default) means dx-toolkit (stable) on prod, and
         # dx-toolkit-beta on all other systems.
-        if dxpy.APISERVER_HOST == "preprodapi.dnanexus.com" or dxpy.APISERVER_HOST == "api.dnanexus.com":
-            dx_toolkit_autodep = "stable"
-        else:
-            dx_toolkit_autodep = "beta"
+        dx_toolkit_autodep = "stable" if dxpy.APISERVER_HOST == "api.dnanexus.com" else "beta"
 
     build_options = {'dx_toolkit_autodep': dx_toolkit_autodep}
 
@@ -521,12 +518,9 @@ def build_and_upload_locally(src_dir, mode, overwrite=False, publish=False, dest
 
         try:
             if dx_toolkit_autodep == "auto":
-                # "auto" (the default) means dx-toolkit (stable) on preprod and prod,
-                # and dx-toolkit-beta on all other systems.
-                if dxpy.APISERVER_HOST == "preprodapi.dnanexus.com" or dxpy.APISERVER_HOST == "api.dnanexus.com":
-                    dx_toolkit_autodep = "stable"
-                else:
-                    dx_toolkit_autodep = "beta"
+                # "auto" (the default) means dx-toolkit (stable) on
+                # prod, and dx-toolkit-beta on all other systems.
+                dx_toolkit_autodep = "stable" if dxpy.APISERVER_HOST == "api.dnanexus.com" else "beta"
             applet_id, applet_spec = dxpy.app_builder.upload_applet(
                 src_dir,
                 bundled_resources,
@@ -602,7 +596,7 @@ def main(**kwargs):
     else:
         args = parser.parse_args(**kwargs)
 
-    if dxpy.AUTH_HELPER is None:
+    if dxpy.AUTH_HELPER is None and not args.dry_run:
         parser.error('Authentication required to build an executable on the platform; please run "dx login" first')
 
     if args.src_dir is None:
